context property

ErrorContext? context
final

Additional contextual information which is available for this exception.

Varies based on the service that generated the exception.

Implementation

final ErrorContext? context;