GetReplicaResult class Key-Value

Contains the results of a Get-From-Replica operation.

Constructors

GetReplicaResult({required Object? content, required Cas cas, required bool isReplica})
const

Properties

cas Cas
The cas of the document, as it is known by the replica.
final
content Object?
The content of the document, as it existed on the replica.
final
hashCode int
The hash code for this object.
no setterinherited
isReplica bool
Indicates whether this result came from a replica or the primary.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited