MutateInMacro enum Key-Value

A macro that can be passed to a Mutate-In operation (see MutateInSpec) to write special values such as the expiry, CAS, etc.

Inheritance
Available extensions

Values

cas → const MutateInMacro

References the CAS of a document.

const MutateInMacro(r'${Mutation.CAS}')
seqNo → const MutateInMacro

References the sequence number of a document.

const MutateInMacro(r'${Mutation.seqno}')
valueCrc32c → const MutateInMacro

References the crc32 of the value of a document.

const MutateInMacro(r'${Mutation.value_crc32c}')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MutateInMacro>
A constant List of the values in this enum, in order of their declaration.