PasswordAuthenticator.ldapCompatible constructor
Creates a LDAP compatible password authenticator which is insecure if not used with TLS.
Please note that this is insecure and will leak user credentials on the wire to eavesdroppers. This should only be enabled in trusted environments.
Implementation
const PasswordAuthenticator.ldapCompatible({
required this.username,
required this.password,
}) : allowedSaslMechanisms = const ['PLAIN'];