TouchOptions class Key-Value

Options for Collection.touch.

Inheritance

Constructors

TouchOptions({DurabilityLevel? durabilityLevel, Duration? timeout})
const

Properties

durabilityLevel DurabilityLevel?
The level of synchronous durability for this operation.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration?
The timeout for this operation.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited