context property
Additional contextual information which is available for this exception.
Varies based on the service that generated the exception.
Implementation
final ErrorContext? context;
Additional contextual information which is available for this exception.
Varies based on the service that generated the exception.
final ErrorContext? context;